==> v1.7.7.22.tar.gz: manaplus/src/resources/loaders/walklayerloader.cpp <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2004-2009  The Mana World Development Team
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011-2017  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "resources/resourcemanager/resourcemanager.h"

#include "navigationmanager.h"

#include "resources/map/walklayer.h"

#include "resources/loaders/walklayerloader.h"

#include "utils/checkutils.h"

#include "debug.h"

#ifndef DYECMD
struct WalkLayerLoader final
{
    A_DEFAULT_COPY(WalkLayerLoader)

    const std::string name;
    const Map *const map;

    static Resource *load(const void *const v)
    {
        if (v == nullptr)
            return nullptr;

        const WalkLayerLoader *const rl = static_cast<const
            WalkLayerLoader *>(v);
        Resource *const resource = NavigationManager::loadWalkLayer(rl->map);
        if (resource == nullptr)
            reportAlways("WalkLayer creation error");
        return resource;
    }
};

WalkLayer *Loader::getWalkLayer(const std::string &name,
                                Map *const map)
{
    WalkLayerLoader rl = {name, map};
    return static_cast<WalkLayer*>(ResourceManager::get("walklayer_" + name,
        WalkLayerLoader::load, &rl));
}
#else  // DYECMD

WalkLayer *Loader::getWalkLayer(const std::string &name A_UNUSED,
                                Map *const map A_UNUSED)
{
    return nullptr;
}
#endif  // DYECMD

==> v1.8.12.8.tar.gz: manaplus/src/resources/loaders/walklayerloader.cpp <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2004-2009  The Mana World Development Team
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011-2018  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "resources/resourcemanager/resourcemanager.h"

#include "navigationmanager.h"

#include "resources/map/walklayer.h"

#include "resources/loaders/walklayerloader.h"

#include "utils/checkutils.h"

#include "debug.h"

#ifndef DYECMD
struct WalkLayerLoader final
{
    A_DEFAULT_COPY(WalkLayerLoader)

    const std::string name;
    const Map *const map;

    static Resource *load(const void *const v)
    {
        if (v == nullptr)
            return nullptr;

        const WalkLayerLoader *const rl = static_cast<const
            WalkLayerLoader *>(v);
        Resource *const resource = NavigationManager::loadWalkLayer(rl->map);
        if (resource == nullptr)
            reportAlways("WalkLayer creation error")
        return resource;
    }
};

WalkLayer *Loader::getWalkLayer(const std::string &name,
                                Map *const map)
{
    WalkLayerLoader rl = {name, map};
    return static_cast<WalkLayer*>(ResourceManager::get("walklayer_" + name,
        WalkLayerLoader::load, &rl));
}
#else  // DYECMD

WalkLayer *Loader::getWalkLayer(const std::string &name A_UNUSED,
                                Map *const map A_UNUSED)
{
    return nullptr;
}
#endif  // DYECMD
